# Context Weave AI utils package

This repo hosts the source code for the utils package for [Context Weave AI](https://contextweave.ai/).

## Setup dev environment

1. Create virtual environment: `conda create -n context-weave-utils-env -y python=3.10`
1. Activate virtual environment: `conda activate context-weave-utils-env`
1. Install dependencies: `pip install --upgrade -r requirements.txt`
